################################
Open-source models using PyPSA
################################


This section provides examples of open-source models using PyPSA:


- **European** energy system model `PyPSA-Eur <https://github.com/PyPSA/pypsa-eur>`_, maintained by `pypsa.org <https://pypsa.org>`_
- **German** energy system model `PyPSA-DE <https://github.com/PyPSA/pypsa-de>`_, maintained by `pypsa.org <https://pypsa.org>`_
- **Global** energy system model `PyPSA-Earth <https://github.com/pypsa-meets-earth/pypsa-earth>`_, maintained by `pypsa-meets-earth <https://pypsa-meets-earth.github.io/>`_
- **United States** energy system model `PyPSA-USA <https://github.com/pypsa/pypsa-usa>`_, maintained by Stanford University
- **Chinese** power and heat sector-coupling model `PyPSA-China-PIK <https://github.com/pik-piam/PyPSA-China-PIK>`__, maintained by `PIK <https://www.pik-potsdam.de>`__ based on a `previous version <https://github.com/Xiaowei-Z/PyPSA-China>`_
- **Australian** capacity expansion model `ISPyPSA <https://github.com/Open-ISP/ISPyPSA>`__, maintained by `CEEM University of New South Wales <https://ceem.unsw.edu.au/>`_
- **South-African** electricity model `PyPSA-RSA <https://github.com/MeridianEconomics/pypsa-rsa>`__, maintained by Meridian Economics based on a previous version `PyPSA-ZA <https://github.com/PyPSA/pypsa-za>`_
- **Vietnamese** electricity model `PyPSA-VN <https://github.com/fiasresna/pypsa-vn>`_, developed by FIAS
- **Polish** power system model `PyPSA-PL <https://github.com/instrat-pl/pypsa-pl>`_, developed by Instrat.pl
- **United Kingdom** power system model `PyPSA-UK <https://github.com/ember-climate/pypsa-uk>`__, maintained by Ember
- **Great Britain** power system model `PyPSA-GB <https://github.com/andrewlyden/PyPSA-GB>`__, maintained by the University of Edinburgh
- **Great Britain** power system model `PyPSA-FES <https://github.com/centrefornetzero/pypsa-fes>`__, maintained by Octopus Energy's `Centre for Net Zero <https://www.centrefornetzero.org/>`__.
- **Spanish** energy system model `PyPSA-Spain <https://github.com/cristobal-GC/pypsa-spain>`__, maintained by Polytechnic University of Madrid
- **Central and Eastern Europe** power system model `PyPSA-CEE <https://github.com/ember-climate/pypsa-cee>`__, maintained by Ember
- **Brazilian** power system model `PyPSA-Brazil <https://gitlab.com/dlr-ve/esy/open-brazil-energy-data/open-brazilian-energy-data>`_ from `this paper <https://doi.org/10.1038/s41597-023-01992-9>`__, developed by the German Aerospace Center (DLR)
- **ASEAN** power system model `TZ-APG <https://www.transitionzero.org/products/tz-asean-power-grid-model/>`__, maintained by TransitionZero
- **South Korean** energy system model `PyPSA-KR <https://energyinnovation.korea.ac.kr/research/code-and-data>`_, developed by Korea University
- **Japanese** `power system model <https://github.com/smdumlao/demandfingerprint/tree/main/papers/coaldecommissioning>`_
- **New Zealand** energy system model `PyPSA-NZ <https://github.com/energyLS/pypsa-nz>`__, developed by Leon Schumm
- Build your own global zero emission scenario `model.energy <https://model.energy/>`_, maintained by `pypsa.org <pypsa.org>`_
- Define your own sector-coupled European scenarios `model.energy/scenarios <https://model.energy/scenarios/>`_, maintained by `pypsa.org <pypsa.org>`_
- Build your own green energy import supply chain `model.energy/products <https://model.energy/green-energy-imports/>`_, maintained by `pypsa.org <pypsa.org>`_
- See how the future German energy system might operate with today's weather `model.energy/future <https://model.energy/future/>`_
- Transport of chemical energy carriers to Germany `TRACE <https://github.com/euronion/trace>`_
- Transmission grid optimisation `eTraGo <https://github.com/openego/eTraGo>`_
- Distribution grid optimisation `dDisGo <https://github.com/openego/eDisGo>`_
- `Chinese model for hydro power and storage <https://arxiv.org/abs/1810.10347>`_
- `Rural district heating networks in Germany with piecewised linearised cost functions <https://github.com/TomKae00/Decarboruralareas/>`_
